@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.031_01';
+our $VERSION = '1.035_001';
 
 =head1 NAME
 
@@ -26,6 +26,7 @@ have a C compiler.
 
 use Config;
 use Archive::Zip ();
+use ExtUtils::MakeMaker (); # just for maybe_command()
 use Cwd ();
 use File::Basename ();
 use File::Find ();
@@ -1731,11 +1732,13 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
+Roderich Schupp E<lt>rschupp@cpan.orgE<gt>
+
 You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
 
-Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
+Please submit bug reports to E<lt>bug-par-packer@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
@@ -1744,6 +1747,6 @@ Copyright 2004-2010 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See F<LICENSE>.
 
 =cut
